@@ -4,9 +4,11 @@ use crate::error::{
 };
 use git2::{
 	Commit,
+	DescribeOptions,
 	Repository as GitRepository,
 	Sort,
 };
+use glob::Pattern;
 use indexmap::IndexMap;
 use std::io;
 use std::path::PathBuf;
@@ -39,7 +41,8 @@ impl Repository {
 	pub fn commits(
 		&self,
 		range: Option<String>,
-		path: Option<String>,
+		include_path: Option<Vec<Pattern>>,
+		exclude_path: Option<Vec<Pattern>>,
 	) -> Result<Vec<Commit>> {
 		let mut revwalk = self.inner.revwalk()?;
 		revwalk.set_sorting(Sort::TIME | Sort::TOPOLOGICAL)?;
@@ -52,7 +55,7 @@ impl Repository {
 			.filter_map(|id| id.ok())
 			.filter_map(|id| self.inner.find_commit(id).ok())
 			.collect();
-		if let Some(commit_path) = path {
+		if include_path.is_some() || exclude_path.is_some() {
 			commits = commits
 				.into_iter()
 				.filter(|commit| {
@@ -62,11 +65,23 @@ impl Repository {
 							prev_commit.tree().ok().as_ref(),
 							None,
 						) {
-							return diff.deltas().any(|delta| {
-								delta.new_file().path().map_or(false, |path| {
-									path.starts_with(&commit_path)
-								})
-							});
+							return diff
+								.deltas()
+								.filter_map(|delta| delta.new_file().path())
+								.any(|new_file_path| {
+									if let Some(include_path) = &include_path {
+										include_path.iter().any(|glob| {
+											glob.matches_path(new_file_path)
+										})
+									} else if let Some(exclude_path) = &exclude_path
+									{
+										!exclude_path.iter().any(|glob| {
+											glob.matches_path(new_file_path)
+										})
+									} else {
+										false
+									}
+								});
 						}
 					}
 					false
@@ -76,12 +91,23 @@ impl Repository {
 		Ok(commits)
 	}
 
+	/// Returns the current tag.
+	///
+	/// It is the same as running `git describe --tags`
+	pub fn current_tag(&self) -> Option<String> {
+		self.inner
+			.describe(DescribeOptions::new().describe_tags())
+			.ok()
+			.and_then(|describe| describe.format(None).ok())
+	}
+
 	/// Parses and returns a commit-tag map.
 	///
 	/// It collects lightweight and annotated tags.
 	pub fn tags(
 		&self,
 		pattern: &Option<String>,
+		topo_order: bool,
 	) -> Result<IndexMap<String, String>> {
 		let mut tags: Vec<(Commit, String)> = Vec::new();
 		let tag_names = self.inner.tag_names(pattern.as_deref())?;
@@ -100,7 +126,9 @@ impl Repository {
 				}
 			}
 		}
-		tags.sort_by(|a, b| a.0.time().seconds().cmp(&b.0.time().seconds()));
+		if !topo_order {
+			tags.sort_by(|a, b| a.0.time().seconds().cmp(&b.0.time().seconds()));
+		}
 		Ok(tags
 			.into_iter()
 			.map(|(a, b)| (a.id().to_string(), b))
@@ -151,7 +179,7 @@ mod test {
 				.unwrap()
 				.to_path_buf(),
 		)?;
-		let commits = repository.commits(None, None)?;
+		let commits = repository.commits(None, None, None)?;
 		let last_commit = AppCommit::from(&commits.first().unwrap().clone());
 		assert_eq!(get_last_commit_hash()?, last_commit.id);
 		if let Err(e) = last_commit.into_conventional() {
@@ -164,7 +192,7 @@ mod test {
 				}
 			}
 		}
-		let tags = repository.tags(&None)?;
+		let tags = repository.tags(&None, false)?;
 		assert_eq!(&get_last_tag()?, tags.last().unwrap().1);
 		Ok(())
 	}
