@@ -1,3 +1,4 @@
+use git_cliff_core::glob::Pattern;
 use git_cliff_core::DEFAULT_CONFIG;
 use std::path::PathBuf;
 use structopt::clap::AppSettings;
@@ -20,7 +21,7 @@ use structopt::StructOpt;
 pub struct Opt {
 	/// Increases the logging verbosity.
 	#[structopt(short, long, parse(from_occurrences), alias = "debug")]
-	pub verbose:     u8,
+	pub verbose:      u8,
 	/// Sets the configuration file.
 	#[structopt(
 		short,
@@ -29,25 +30,31 @@ pub struct Opt {
 		value_name = "PATH",
 		default_value = DEFAULT_CONFIG,
 	)]
-	pub config:      PathBuf,
+	pub config:       PathBuf,
 	/// Sets the working directory.
 	#[structopt(short, long, env, value_name = "PATH")]
-	pub workdir:     Option<PathBuf>,
+	pub workdir:      Option<PathBuf>,
 	/// Sets the git repository.
 	#[structopt(short, long, env, value_name = "PATH")]
-	pub repository:  Option<PathBuf>,
-	/// Sets the directory to parse commits from.
-	#[structopt(long, env, value_name = "PATH")]
-	pub commit_path: Option<String>,
+	pub repository:   Option<PathBuf>,
+	/// Sets the path to include related commits.
+	#[structopt(long, env, value_name = "PATTERN")]
+	pub include_path: Option<Vec<Pattern>>,
+	/// Sets the path to exclude related commits.
+	#[structopt(long, env, value_name = "PATTERN")]
+	pub exclude_path: Option<Vec<Pattern>>,
+	/// Sets custom commit messages to include in the changelog.
+	#[structopt(long, env, value_name = "MSG")]
+	pub with_commit:  Option<Vec<String>>,
 	/// Prepends entries to the given changelog file.
 	#[structopt(short, long, env, value_name = "PATH")]
-	pub prepend:     Option<PathBuf>,
+	pub prepend:      Option<PathBuf>,
 	/// Writes output to the given file.
 	#[structopt(short, long, env, value_name = "PATH")]
-	pub output:      Option<PathBuf>,
+	pub output:       Option<PathBuf>,
 	/// Sets the tag for the latest version.
 	#[structopt(short, long, env, value_name = "TAG", allow_hyphen_values = true)]
-	pub tag:         Option<String>,
+	pub tag:          Option<String>,
 	/// Sets the template for the changelog body.
 	#[structopt(
 		short,
@@ -56,16 +63,22 @@ pub struct Opt {
 		value_name = "TEMPLATE",
 		allow_hyphen_values = true
 	)]
-	pub body:        Option<String>,
+	pub body:         Option<String>,
 	/// Writes the default configuration file to cliff.toml
 	#[structopt(short, long)]
-	pub init:        bool,
+	pub init:         bool,
 	/// Processes the commits starting from the latest tag.
 	#[structopt(short, long)]
-	pub latest:      bool,
+	pub latest:       bool,
+	/// Processes the commits that belong to the current tag.
+	#[structopt(long)]
+	pub current:      bool,
 	/// Processes the commits that do not belong to a tag.
 	#[structopt(short, long)]
-	pub unreleased:  bool,
+	pub unreleased:   bool,
+	/// Sorts the tags topologically.
+	#[structopt(long)]
+	pub topo_order:   bool,
 	/// Strips the given parts from the changelog.
 	#[structopt(
 		short,
@@ -73,16 +86,15 @@ pub struct Opt {
 		value_name = "PART",
 		possible_values = &["header", "footer", "all"]
 	)]
-	pub strip:       Option<String>,
+	pub strip:        Option<String>,
 	/// Sets the commit range to process.
 	#[structopt(value_name = "RANGE")]
-	pub range:       Option<String>,
-
+	pub range:        Option<String>,
 	/// Sets sorting of the commits inside sections.
 	#[structopt(
 		long,
 		possible_values = &["oldest", "newest"],
 		default_value = "oldest"
 	)]
-	pub sort: String,
+	pub sort:         String,
 }
