@@ -71,7 +71,7 @@ pub fn run(mut args: Opt) -> Result<()> {
 		EmbeddedConfig::parse()?
 	};
 
-	// Update the configuration based on command line arguments.
+	// Update the configuration based on command line arguments and vice versa.
 	match args.strip.as_deref() {
 		Some("header") => {
 			config.changelog.header = None;
@@ -96,13 +96,50 @@ pub fn run(mut args: Opt) -> Result<()> {
 	if let Some(template) = args.body {
 		config.changelog.body = template;
 	}
+	if args.sort == "oldest" {
+		if let Some(ref sort_commits) = config.git.sort_commits {
+			args.sort = sort_commits.to_string();
+		}
+	}
+	if !args.topo_order {
+		if let Some(topo_order) = config.git.topo_order {
+			args.topo_order = topo_order;
+		}
+	}
 
 	// Initialize the git repository.
 	let repository =
 		Repository::init(args.repository.unwrap_or(env::current_dir()?))?;
 
 	// Parse tags.
-	let mut tags = repository.tags(&config.git.tag_pattern)?;
+	let mut tags = repository.tags(&config.git.tag_pattern, args.topo_order)?;
+
+	// Skip tags.
+	let skip_regex = config.git.skip_tags.as_ref();
+	let ignore_regex = config.git.ignore_tags.as_ref();
+	tags = tags
+		.into_iter()
+		.filter(|(_, name)| {
+			// Keep skip tags to drop commits in the later stage.
+			let skip = skip_regex.map(|r| r.is_match(name)).unwrap_or_default();
+
+			let ignore = ignore_regex
+				.map(|r| {
+					if r.as_str().trim().is_empty() {
+						return false;
+					}
+
+					let ignore_tag = r.is_match(name);
+					if ignore_tag {
+						trace!("Ignoring release: {}", name)
+					}
+					ignore_tag
+				})
+				.unwrap_or_default();
+
+			skip || !ignore
+		})
+		.collect();
 
 	// Parse commits.
 	let mut commit_range = args.range;
@@ -110,19 +147,37 @@ pub fn run(mut args: Opt) -> Result<()> {
 		if let Some(last_tag) = tags.last().map(|(k, _)| k) {
 			commit_range = Some(format!("{}..HEAD", last_tag));
 		}
-	} else if args.latest {
+	} else if args.latest || args.current {
 		if tags.len() < 2 {
 			return Err(Error::ChangelogError(String::from(
-				"Latest tag cannot be processed",
+				"Not enough tags exist for processing the latest/current tag",
 			)));
-		} else if let (Some(tag1), Some(tag2)) = (
-			tags.get_index(tags.len() - 2).map(|(k, _)| k),
-			tags.get_index(tags.len() - 1).map(|(k, _)| k),
+		}
+		let mut tag_index = tags.len() - 2;
+		if args.current {
+			if let Some(current_tag_index) =
+				repository.current_tag().as_ref().and_then(|tag| {
+					tags.iter()
+						.enumerate()
+						.find(|(_, (_, v))| v == &tag)
+						.map(|(i, _)| i)
+				}) {
+				tag_index = current_tag_index - 1;
+			} else {
+				return Err(Error::ChangelogError(String::from(
+					"No tag exists for the current commit",
+				)));
+			}
+		}
+		if let (Some(tag1), Some(tag2)) = (
+			tags.get_index(tag_index).map(|(k, _)| k),
+			tags.get_index(tag_index + 1).map(|(k, _)| k),
 		) {
 			commit_range = Some(format!("{}..{}", tag1, tag2));
 		}
 	}
-	let commits = repository.commits(commit_range, args.commit_path)?;
+	let commits =
+		repository.commits(commit_range, args.include_path, args.exclude_path)?;
 
 	// Update tags.
 	if let Some(tag) = args.tag {
@@ -162,6 +217,17 @@ pub fn run(mut args: Opt) -> Result<()> {
 		}
 	}
 
+	// Add custom commit messages to the latest release.
+	if let Some(custom_commits) = args.with_commit {
+		if let Some(latest_release) = releases.iter_mut().last() {
+			custom_commits.iter().for_each(|commit_message| {
+				latest_release
+					.commits
+					.push(Commit::new(String::new(), commit_message.to_string()))
+			});
+		}
+	}
+
 	// Set the previous release if needed.
 	if args.latest {
 		if let Some((commit_id, version)) = tags.get_index(tags.len() - 2) {
